@@ -1,14 +1,14 @@
 """
 Type annotations for databrew service literal definitions.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/literals.html)
+[Open documentation](./literals.md)
 
 Usage::
 
     ```python
-    from mypy_boto3_databrew.literals import CompressionFormat
+    from mypy_boto3_databrew.literals import CompressionFormatType
 
-    data: CompressionFormat = "BROTLI"
+    data: CompressionFormatType = "BROTLI"
     ```
 """
 import sys
@@ -20,11 +20,11 @@ else:
 
 
 __all__ = (
-    "CompressionFormat",
-    "EncryptionMode",
-    "InputFormat",
-    "JobRunState",
-    "JobType",
+    "CompressionFormatType",
+    "EncryptionModeType",
+    "InputFormatType",
+    "JobRunStateType",
+    "JobTypeType",
     "ListDatasetsPaginatorName",
     "ListJobRunsPaginatorName",
     "ListJobsPaginatorName",
@@ -32,27 +32,27 @@ __all__ = (
     "ListRecipeVersionsPaginatorName",
     "ListRecipesPaginatorName",
     "ListSchedulesPaginatorName",
-    "LogSubscription",
-    "Order",
-    "OrderedBy",
-    "OutputFormat",
-    "ParameterType",
-    "SampleMode",
-    "SampleType",
-    "SessionStatus",
-    "Source",
+    "LogSubscriptionType",
+    "OrderType",
+    "OrderedByType",
+    "OutputFormatType",
+    "ParameterTypeType",
+    "SampleModeType",
+    "SampleTypeType",
+    "SessionStatusType",
+    "SourceType",
 )
 
 
-CompressionFormat = Literal[
+CompressionFormatType = Literal[
     "BROTLI", "BZIP2", "DEFLATE", "GZIP", "LZ4", "LZO", "SNAPPY", "ZLIB", "ZSTD"
 ]
-EncryptionMode = Literal["SSE-KMS", "SSE-S3"]
-InputFormat = Literal["CSV", "EXCEL", "JSON", "PARQUET"]
-JobRunState = Literal[
+EncryptionModeType = Literal["SSE-KMS", "SSE-S3"]
+InputFormatType = Literal["CSV", "EXCEL", "JSON", "PARQUET"]
+JobRunStateType = Literal[
     "FAILED", "RUNNING", "STARTING", "STOPPED", "STOPPING", "SUCCEEDED", "TIMEOUT"
 ]
-JobType = Literal["PROFILE", "RECIPE"]
+JobTypeType = Literal["PROFILE", "RECIPE"]
 ListDatasetsPaginatorName = Literal["list_datasets"]
 ListJobRunsPaginatorName = Literal["list_job_runs"]
 ListJobsPaginatorName = Literal["list_jobs"]
@@ -60,14 +60,14 @@ ListProjectsPaginatorName = Literal["list_projects"]
 ListRecipeVersionsPaginatorName = Literal["list_recipe_versions"]
 ListRecipesPaginatorName = Literal["list_recipes"]
 ListSchedulesPaginatorName = Literal["list_schedules"]
-LogSubscription = Literal["DISABLE", "ENABLE"]
-Order = Literal["ASCENDING", "DESCENDING"]
-OrderedBy = Literal["LAST_MODIFIED_DATE"]
-OutputFormat = Literal["AVRO", "CSV", "GLUEPARQUET", "JSON", "ORC", "PARQUET", "XML"]
-ParameterType = Literal["Datetime", "Number", "String"]
-SampleMode = Literal["CUSTOM_ROWS", "FULL_DATASET"]
-SampleType = Literal["FIRST_N", "LAST_N", "RANDOM"]
-SessionStatus = Literal[
+LogSubscriptionType = Literal["DISABLE", "ENABLE"]
+OrderType = Literal["ASCENDING", "DESCENDING"]
+OrderedByType = Literal["LAST_MODIFIED_DATE"]
+OutputFormatType = Literal["AVRO", "CSV", "GLUEPARQUET", "JSON", "ORC", "PARQUET", "XML"]
+ParameterTypeType = Literal["Datetime", "Number", "String"]
+SampleModeType = Literal["CUSTOM_ROWS", "FULL_DATASET"]
+SampleTypeType = Literal["FIRST_N", "LAST_N", "RANDOM"]
+SessionStatusType = Literal[
     "ASSIGNED",
     "FAILED",
     "INITIALIZING",
@@ -79,4 +79,4 @@ SessionStatus = Literal[
     "TERMINATING",
     "UPDATING",
 ]
-Source = Literal["DATA-CATALOG", "DATABASE", "S3"]
+SourceType = Literal["DATA-CATALOG", "DATABASE", "S3"]
